@@ -16,17 +16,35 @@
 #
 # You should have received a copy of the GNU Lesser General Public License
 # along with pygal. If not, see <http://www.gnu.org/licenses/>.
-
 """Various config options tested on one chart type or more"""
 
 from tempfile import NamedTemporaryFile
 
 from pygal import (
-    XY, Bar, Box, Config, DateLine, DateTimeLine, Dot, Funnel, Gauge,
-    Histogram, HorizontalBar, HorizontalLine, HorizontalStackedBar,
-    HorizontalStackedLine, Line, Pie, Pyramid, Radar, SolidGauge,
-    TimeDeltaLine, TimeLine, Treemap, formatters)
-from pygal._compat import _ellipsis, u
+    XY,
+    Bar,
+    Box,
+    Config,
+    DateLine,
+    DateTimeLine,
+    Dot,
+    Funnel,
+    Gauge,
+    Histogram,
+    HorizontalBar,
+    HorizontalLine,
+    HorizontalStackedBar,
+    HorizontalStackedLine,
+    Line,
+    Pie,
+    Pyramid,
+    Radar,
+    SolidGauge,
+    TimeDeltaLine,
+    TimeLine,
+    Treemap,
+    formatters,
+)
 from pygal.graph.dual import Dual
 from pygal.graph.horizontal import HorizontalGraph
 from pygal.graph.map import BaseMap
@@ -59,7 +77,8 @@ def test_config_behaviours():
         fill=True,
         pretty_print=True,
         no_prefix=True,
-        x_labels=['a', 'b', 'c'])
+        x_labels=['a', 'b', 'c']
+    )
     line2.add('_', [1, 2, 3])
     l2 = line2.render()
     assert l1 == l2
@@ -99,6 +118,7 @@ def test_config_behaviours():
 
 def test_config_alterations_class():
     """Assert a config can be changed on config class"""
+
     class LineConfig(Config):
         no_prefix = True
         show_legend = False
@@ -122,6 +142,7 @@ def test_config_alterations_class():
 
 def test_config_alterations_instance():
     """Assert a config can be changed on instance"""
+
     class LineConfig(Config):
         no_prefix = True
         show_legend = False
@@ -146,6 +167,7 @@ def test_config_alterations_instance():
 
 def test_config_alterations_kwargs():
     """Assert a config can be changed with keyword args"""
+
     class LineConfig(Config):
         no_prefix = True
         show_legend = False
@@ -181,7 +203,7 @@ def test_config_alterations_kwargs():
 def test_logarithmic():
     """Test logarithmic option"""
     line = Line(logarithmic=True)
-    line.add('_', [1, 10 ** 10, 1])
+    line.add('_', [1, 10**10, 1])
     q = line.render_pyquery()
     assert len(q(".axis.x")) == 0
     assert len(q(".axis.y")) == 1
@@ -227,25 +249,28 @@ def test_logarithmic_bad_interpolation():
 def test_logarithmic_big_scale():
     """Test logarithmic option with a large range of value"""
     line = Line(logarithmic=True)
-    line.add('_', [10 ** -10, 10 ** 10, 1])
+    line.add('_', [10**-10, 10**10, 1])
     q = line.render_pyquery()
     assert len(q(".y.axis .guides")) == 21
 
 
 def test_value_formatter():
     """Test value formatter option"""
-    line = Line(value_formatter=lambda x: str(x) + u('‰'))
-    line.add('_', [10 ** 4, 10 ** 5, 23 * 10 ** 4])
+    line = Line(value_formatter=lambda x: str(x) + '‰')
+    line.add('_', [10**4, 10**5, 23 * 10**4])
     q = line.render_pyquery()
     assert len(q(".y.axis .guides")) == 11
-    assert q(".axis.y text").map(texts) == list(map(
-        lambda x: str(x) + u('‰'), map(float, range(20000, 240000, 20000))))
+    assert q(".axis.y text").map(texts) == list(
+        map(
+            lambda x: str(x) + '‰', map(float, range(20000, 240000, 20000))
+        )
+    )
 
 
 def test_logarithmic_small_scale():
     """Test logarithmic with a small range of values"""
     line = Line(logarithmic=True)
-    line.add('_', [1 + 10 ** 10, 3 + 10 ** 10, 2 + 10 ** 10])
+    line.add('_', [1 + 10**10, 3 + 10**10, 2 + 10**10])
     q = line.render_pyquery()
     assert len(q(".y.axis .guides")) == 11
 
@@ -253,16 +278,18 @@ def test_logarithmic_small_scale():
 def test_human_readable():
     """Test human readable option"""
     line = Line()
-    line.add('_', [10 ** 4, 10 ** 5, 23 * 10 ** 4])
+    line.add('_', [10**4, 10**5, 23 * 10**4])
     q = line.render_pyquery()
-    assert q(".axis.y text").map(texts) == list(map(
-        str, range(20000, 240000, 20000)))
+    assert q(".axis.y text").map(texts) == list(
+        map(str, range(20000, 240000, 20000))
+    )
 
     line.value_formatter = formatters.human_readable
 
     q = line.render_pyquery()
-    assert q(".axis.y text").map(texts) == list(map(
-        lambda x: '%dk' % x, range(20, 240, 20)))
+    assert q(".axis.y text").map(texts) == list(
+        map(lambda x: '%dk' % x, range(20, 240, 20))
+    )
 
 
 def test_show_legend():
@@ -292,17 +319,16 @@ def test_no_data():
     line = Line()
     q = line.render_pyquery()
     assert q(".text-overlay text").text() == "No data"
-    line.no_data_text = u("þæ®þæ€€&ĳ¿’€")
+    line.no_data_text = "þæ®þæ€€&ĳ¿’€"
     q = line.render_pyquery()
-    assert q(".text-overlay text").text() == u("þæ®þæ€€&ĳ¿’€")
+    assert q(".text-overlay text").text() == "þæ®þæ€€&ĳ¿’€"
 
 
 def test_include_x_axis(Chart):
     """Test x axis inclusion option"""
     chart = Chart()
-    if Chart in (
-            Pie, Treemap, Radar, Funnel, Dot, Gauge, Histogram, Box, SolidGauge
-    ) or issubclass(Chart, BaseMap):
+    if Chart in (Pie, Treemap, Radar, Funnel, Dot, Gauge, Histogram, Box,
+                 SolidGauge) or issubclass(Chart, BaseMap):
         return
     if not chart._dual:
         data = 100, 200, 150
@@ -312,7 +338,8 @@ def test_include_x_axis(Chart):
     q = chart.render_pyquery()
     # Ghost thing
     yaxis = ".axis.%s .guides text" % (
-        'y' if not getattr(chart, 'horizontal', False) else 'x')
+        'y' if not getattr(chart, 'horizontal', False) else 'x'
+    )
     if not isinstance(chart, Bar):
         assert '0' not in q(yaxis).map(texts)
     else:
@@ -337,7 +364,7 @@ def test_css(Chart):
         svg = chart.render().decode('utf-8')
         assert '#bedead' in svg
 
-        chart = Chart(css=(_ellipsis, 'file://' + f.name))
+        chart = Chart(css=(Ellipsis, 'file://' + f.name))
         chart.add('/', [10, 1, 5])
         svg = chart.render().decode('utf-8')
         assert '#bedead' in svg
@@ -386,9 +413,11 @@ def test_legend_at_bottom(Chart):
 
 def test_x_y_title(Chart):
     """Test x title and y title options"""
-    chart = Chart(title='I Am A Title',
-                  x_title="I am a x title",
-                  y_title="I am a y title")
+    chart = Chart(
+        title='I Am A Title',
+        x_title="I am a x title",
+        y_title="I am a y title"
+    )
     chart.add('1', [4, -5, 123, 59, 38])
     chart.add('2', [89, 0, 8, .12, 8])
     q = chart.render_pyquery()
@@ -397,9 +426,7 @@ def test_x_y_title(Chart):
 
 def test_range(Chart):
     """Test y label major option"""
-    if Chart in (
-            Pie, Treemap, Dot, SolidGauge
-    ) or issubclass(Chart, BaseMap):
+    if Chart in (Pie, Treemap, Dot, SolidGauge) or issubclass(Chart, BaseMap):
         return
     chart = Chart()
     chart.range = (0, 100)
@@ -414,11 +441,10 @@ def test_range(Chart):
 
 def test_x_label_major(Chart):
     """Test x label major option"""
-    if Chart in (
-            Pie, Treemap, Funnel, Dot, Gauge, Histogram, Box, SolidGauge,
-            Pyramid, DateTimeLine, TimeLine, DateLine,
-            TimeDeltaLine
-    ) or issubclass(Chart, (BaseMap, Dual, HorizontalGraph)):
+    if Chart in (Pie, Treemap, Funnel, Dot, Gauge, Histogram, Box, SolidGauge,
+                 Pyramid, DateTimeLine, TimeLine, DateLine,
+                 TimeDeltaLine) or issubclass(
+                     Chart, (BaseMap, Dual, HorizontalGraph)):
         return
     chart = Chart()
     chart.add('test', range(12))
@@ -459,13 +485,10 @@ def test_x_label_major(Chart):
 
 def test_y_label_major(Chart):
     """Test y label major option"""
-    if Chart in (
-            Pie, Treemap, Funnel, Dot, Gauge, Histogram, Box, SolidGauge,
-            HorizontalBar, HorizontalStackedBar,
-            HorizontalStackedLine, HorizontalLine,
-            Pyramid, DateTimeLine, TimeLine, DateLine,
-            TimeDeltaLine
-    ) or issubclass(Chart, BaseMap):
+    if Chart in (Pie, Treemap, Funnel, Dot, Gauge, Histogram, Box, SolidGauge,
+                 HorizontalBar, HorizontalStackedBar, HorizontalStackedLine,
+                 HorizontalLine, Pyramid, DateTimeLine, TimeLine, DateLine,
+                 TimeDeltaLine) or issubclass(Chart, BaseMap):
         return
     chart = Chart()
     data = range(12)
@@ -527,26 +550,26 @@ def test_fill(Chart):
 def test_render_data_uri(Chart):
     """Test the render data uri"""
     chart = Chart(fill=True)
-    chart.add(u('ééé'), [1, 2, 3])
-    chart.add(u('èèè'), [10, 21, 5])
-    assert chart.render_data_uri().startswith(
-        'data:image/svg+xml;charset=utf-8;base64,')
+    chart.add('ééé', [1, 2, 3])
+    chart.add('èèè', [10, 21, 5])
+    assert chart.render_data_uri(
+    ).startswith('data:image/svg+xml;charset=utf-8;base64,')
 
 
 def test_formatters(Chart):
     """Test custom formatters"""
     if Chart._dual or Chart == Box:
         return
-    chart = Chart(
-        formatter=lambda x, chart, serie: '%s%s$' % (x, serie.title))
-    chart.add('_a', [1, 2, {'value': 3, 'formatter': lambda x: u('%s¥') % x}])
-    chart.add('_b', [4, 5, 6], formatter=lambda x: u('%s€') % x)
+    chart = Chart(formatter=lambda x, chart, serie: '%s%s$' % (x, serie.title))
+    chart.add('_a', [1, 2, {'value': 3, 'formatter': lambda x: '%s¥' % x}])
+    chart.add('_b', [4, 5, 6], formatter=lambda x: '%s€' % x)
     chart.x_labels = [2, 4, 6]
     chart.x_labels_major = [4]
     q = chart.render_pyquery()
-    assert set([v.text for v in q(".value")]) == set((
-        u('4€'), u('5€'), u('6€'), '1_a$', '2_a$', u('3¥')) + (
-            ('6_a$', u('15€')) if Chart in (Pie, SolidGauge) else ()))
+    assert set(
+        [v.text for v in q(".value")]
+    ) == set(('4€', '5€', '6€', '1_a$', '2_a$', '3¥') +
+             (('6_a$', '15€') if Chart in (Pie, SolidGauge) else ()))
 
 
 def test_classes(Chart):
@@ -557,17 +580,17 @@ def test_classes(Chart):
     chart = Chart(classes=())
     assert not chart.render_pyquery().attr('class')
 
-    chart = Chart(classes=(_ellipsis,))
+    chart = Chart(classes=(Ellipsis, ))
     assert chart.render_pyquery().attr('class') == 'pygal-chart'
 
-    chart = Chart(classes=('graph',))
+    chart = Chart(classes=('graph', ))
     assert chart.render_pyquery().attr('class') == 'graph'
 
     chart = Chart(classes=('pygal-chart', 'graph'))
     assert chart.render_pyquery().attr('class') == 'pygal-chart graph'
 
-    chart = Chart(classes=(_ellipsis, 'graph'))
+    chart = Chart(classes=(Ellipsis, 'graph'))
     assert chart.render_pyquery().attr('class') == 'pygal-chart graph'
 
-    chart = Chart(classes=('graph', _ellipsis))
+    chart = Chart(classes=('graph', Ellipsis))
     assert chart.render_pyquery().attr('class') == 'graph pygal-chart'
