@@ -21,12 +21,22 @@
 from math import ceil, cos, sin, sqrt
 
 from pygal import stats
-from pygal._compat import is_list_like, is_str, to_str
+from pygal._compat import is_list_like
 from pygal.graph.public import PublicApi
 from pygal.interpolate import INTERPOLATIONS
 from pygal.util import (
-    cached_property, compute_scale, cut, decorate, filter_kwargs, get_text_box,
-    get_texts_box, majorize, rad, reverse_text_len, split_title, truncate
+    cached_property,
+    compute_scale,
+    cut,
+    decorate,
+    filter_kwargs,
+    get_text_box,
+    get_texts_box,
+    majorize,
+    rad,
+    reverse_text_len,
+    split_title,
+    truncate,
 )
 from pygal.view import LogView, ReverseView, View, XYLogView
 
@@ -545,10 +555,10 @@ class Graph(PublicApi):
                 classes.append('top')
             classes = ' '.join(classes)
 
-        self.svg.node(node, 'desc', class_="x " + classes).text = to_str(x)
-        self.svg.node(node, 'desc', class_="y " + classes).text = to_str(y)
+        self.svg.node(node, 'desc', class_="x " + classes).text = str(x)
+        self.svg.node(node, 'desc', class_="y " + classes).text = str(y)
         if xlabel:
-            self.svg.node(node, 'desc', class_="x_label").text = to_str(xlabel)
+            self.svg.node(node, 'desc', class_="x_label").text = str(xlabel)
 
     def _static_value(
             self,
@@ -649,7 +659,7 @@ class Graph(PublicApi):
 
     @property
     def _default_formatter(self):
-        return to_str
+        return str
 
     @property
     def _y_format(self):
@@ -897,7 +907,7 @@ class Graph(PublicApi):
         return len(self.all_series)
 
     def _x_label_format_if_value(self, label):
-        if not is_str(label):
+        if not isinstance(label, str):
             return self._x_format(label)
         return label
 
@@ -943,7 +953,7 @@ class Graph(PublicApi):
                 if isinstance(y_label, dict):
                     pos = self._adapt(y_label.get('value'))
                     title = y_label.get('label', self._y_format(pos))
-                elif is_str(y_label):
+                elif isinstance(y_label, str):
                     pos = self._adapt(y_pos[i % len(y_pos)])
                     title = y_label
                 else:
